/*

Copyright (c) 2013-2014, Jean-Philippe Côté (www.cote.cc)
All rights reserved.

This library is provided "as is" with no guarantees whatsoever. Use it at your own risk.

*/

package cc.cote.feathers.softkeyboard.keycollections
{
	import cc.cote.feathers.softkeyboard.Key;

	/**
	 * The <code>AllLatinKeyVariants</code> class is an enumeration class that provides values for 
	 * all variants of latin alphabet letters. It mostly serves as a reference template to create 
	 * language-specific key variants classes.
	 */
	public class AllLatinKeyVariants
	{
		
		/** Latin letter A variants */
		public static const A:Vector.<Key> = new <Key>[
			new Key('à'.charCodeAt()),
			new Key('á'.charCodeAt()),
			new Key('â'.charCodeAt()),
			new Key('ã'.charCodeAt()),
			new Key('ā'.charCodeAt()),
			new Key('ă'.charCodeAt()),
			new Key('ȧ'.charCodeAt()),
			new Key('ä'.charCodeAt()),
			new Key('ả'.charCodeAt()),
			new Key('å'.charCodeAt()),
			new Key('ǎ'.charCodeAt()),
			new Key('ȁ'.charCodeAt()),
			new Key('ą'.charCodeAt()),
			new Key('ạ'.charCodeAt()),
			new Key('ḁ'.charCodeAt()),
			new Key('ẚ'.charCodeAt()),
			new Key('ầ'.charCodeAt()),
			new Key('ấ'.charCodeAt()),
			new Key('ẫ'.charCodeAt()),
			new Key('ẩ'.charCodeAt()),
			new Key('ằ'.charCodeAt()),
			new Key('ắ'.charCodeAt()),
			new Key('ẵ'.charCodeAt()),
			new Key('ẳ'.charCodeAt()),
			new Key('ǡ'.charCodeAt()),
			new Key('ǡ'.charCodeAt()),
			new Key('ǟ'.charCodeAt()),
			new Key('ǻ'.charCodeAt()),
			new Key('ậ'.charCodeAt()),
			new Key('ặ'.charCodeAt()),
			new Key('æ'.charCodeAt()),
			new Key('ǽ'.charCodeAt()),
			new Key('ǣ'.charCodeAt())
		];
		
		/** Latin letter B variants */
		public static const B:Vector.<Key> = new <Key>[
			new Key('ḃ'.charCodeAt()),
			new Key('ɓ'.charCodeAt()),
			new Key('ḅ'.charCodeAt()),
			new Key('ḇ'.charCodeAt()),
			new Key('ƀ'.charCodeAt()),
			new Key('ƃ'.charCodeAt()),
			new Key('ƅ'.charCodeAt())
		];

		/** Latin letter C variants */
		public static const C:Vector.<Key> = new <Key>[
			new Key('ć'.charCodeAt()),
			new Key('ĉ'.charCodeAt()),
			new Key('ċ'.charCodeAt()),
			new Key('č'.charCodeAt()),
			new Key('ƈ'.charCodeAt()),
			new Key('ç'.charCodeAt()),
			new Key('ḉ'.charCodeAt())
		];

		/** Latin letter D variants */
		public static const D:Vector.<Key> = new <Key>[
			new Key('ḋ'.charCodeAt()),
			new Key('ɗ'.charCodeAt()),
			new Key('ḍ'.charCodeAt()),
			new Key('ḏ'.charCodeAt()),
			new Key('ḑ'.charCodeAt()),
			new Key('ḓ'.charCodeAt()),
			new Key('ď'.charCodeAt()),
			new Key('đ'.charCodeAt()),
			new Key('ƌ'.charCodeAt()),
			new Key('ȡ'.charCodeAt())
		];
		
		/** Latin letter E variants */
		public static const E:Vector.<Key> = new <Key>[
			new Key(''.charCodeAt()),
			new Key('é'.charCodeAt()),
			new Key('ê'.charCodeAt()),
			new Key('ẽ'.charCodeAt()),
			new Key('ē'.charCodeAt()),
			new Key('ĕ'.charCodeAt()),
			new Key('ė'.charCodeAt()),
			new Key('ë'.charCodeAt()),
			new Key('ẻ'.charCodeAt()),
			new Key('ě'.charCodeAt()),
			new Key('ȅ'.charCodeAt()),
			new Key('ȇ'.charCodeAt()),
			new Key('ẹ'.charCodeAt()),
			new Key('ȩ'.charCodeAt()),
			new Key('ę'.charCodeAt()),
			new Key('ḙ'.charCodeAt()),
			new Key('ḛ'.charCodeAt()),
			new Key('ề'.charCodeAt()),
			new Key('ế'.charCodeAt()),
			new Key('ễ'.charCodeAt()),
			new Key('ể'.charCodeAt()),
			new Key('ḕ'.charCodeAt()),
			new Key('ḗ'.charCodeAt()),
			new Key('ệ'.charCodeAt()),
			new Key('ḝ'.charCodeAt()),
			new Key('ǝ'.charCodeAt()),
			new Key('ɛ'.charCodeAt())
		];
		
		/** Latin letter F variants */
		public static const F:Vector.<Key> = new <Key>[
			new Key('ḟ'.charCodeAt()),
			new Key('ƒ'.charCodeAt())
		];
		
		/** Latin letter G variants */
		public static const G:Vector.<Key> = new <Key>[
			new Key('ǵ'.charCodeAt()),
			new Key('ĝ'.charCodeAt()),
			new Key('ḡ'.charCodeAt()),
			new Key('ğ'.charCodeAt()),
			new Key('ġ'.charCodeAt()),
			new Key('ǧ'.charCodeAt()),
			new Key('ɠ'.charCodeAt()),
			new Key('ģ'.charCodeAt()),
			new Key('ǥ'.charCodeAt())
		];
		
		/** Latin letter H variants */
		public static const H:Vector.<Key> = new <Key>[
			new Key('ĥ'.charCodeAt()),
			new Key('ḣ'.charCodeAt()),
			new Key('ḧ'.charCodeAt()),
			new Key('ȟ'.charCodeAt()),
			new Key('ƕ'.charCodeAt()),
			new Key('ḥ'.charCodeAt()),
			new Key('ḩ'.charCodeAt()),
			new Key('ḫ'.charCodeAt()),
			new Key('ẖ'.charCodeAt()),
			new Key('ħ'.charCodeAt())
		];
		
		/** Latin letter I variants */
		public static const I:Vector.<Key> = new <Key>[
			new Key('ì'.charCodeAt()),
			new Key('í'.charCodeAt()),
			new Key('î'.charCodeAt()),
			new Key('ĩ'.charCodeAt()),
			new Key('ī'.charCodeAt()),
			new Key('ĭ'.charCodeAt()),
			new Key('ı'.charCodeAt()),
			new Key('ï'.charCodeAt()),
			new Key('ỉ'.charCodeAt()),
			new Key('ǐ'.charCodeAt()),
			new Key('ị'.charCodeAt()),
			new Key('į'.charCodeAt()),
			new Key('ȉ'.charCodeAt()),
			new Key('ḭ'.charCodeAt()),
			new Key('ɨ'.charCodeAt()),
			new Key('ḯ'.charCodeAt()),
			new Key('ĳ'.charCodeAt())
		];
		
		/** Latin letter J variants */
		public static const J:Vector.<Key> = new <Key>[
			new Key('ĵ'.charCodeAt()),
			new Key('ǰ'.charCodeAt())
		];
		
		/** Latin letter K variants */
		public static const K:Vector.<Key> = new <Key>[
			new Key('ḱ'.charCodeAt()),
			new Key('ǩ'.charCodeAt()),
			new Key('ḵ'.charCodeAt()),
			new Key('ƙ'.charCodeAt()),
			new Key('ḳ'.charCodeAt()),
			new Key('ķ'.charCodeAt())
		];
		
		/** Latin letter L variants */
		public static const L:Vector.<Key> = new <Key>[
			new Key('ĺ'.charCodeAt()),
			new Key('ḻ'.charCodeAt()),
			new Key('ḷ'.charCodeAt()),
			new Key('ļ'.charCodeAt()),
			new Key('ḽ'.charCodeAt()),
			new Key('ľ'.charCodeAt()),
			new Key('ŀ'.charCodeAt()),
			new Key('ł'.charCodeAt()),
			new Key('ƚ'.charCodeAt()),
			new Key('ḹ'.charCodeAt()),
			new Key('ȴ'.charCodeAt())
		];
		
		/** Latin letter M variants */
		public static const M:Vector.<Key> = new <Key>[
			new Key('ḿ'.charCodeAt()),
			new Key('ṁ'.charCodeAt()),
			new Key('ṃ'.charCodeAt()),
			new Key('ɯ'.charCodeAt())
		];
		
		/** Latin letter N variants */
		public static const N:Vector.<Key> = new <Key>[
			new Key('ǹ'.charCodeAt()),
			new Key('ń'.charCodeAt()),
			new Key('ñ'.charCodeAt()),
			new Key('ṅ'.charCodeAt()),
			new Key('ň'.charCodeAt()),
			new Key('ŋ'.charCodeAt()),
			new Key('ɲ'.charCodeAt()),
			new Key('ṇ'.charCodeAt()),
			new Key('ņ'.charCodeAt()),
			new Key('ṋ'.charCodeAt()),
			new Key('ṉ'.charCodeAt()),
			new Key('ŉ'.charCodeAt()),
			new Key('ƞ'.charCodeAt()),
			new Key('ȵ'.charCodeAt())
		];
		
		/** Latin letter O variants */
		public static const O:Vector.<Key> = new <Key>[
			new Key('ò'.charCodeAt()),
			new Key('ó'.charCodeAt()),
			new Key('ô'.charCodeAt()),
			new Key('õ'.charCodeAt()),
			new Key('ō'.charCodeAt()),
			new Key('ŏ'.charCodeAt()),
			new Key('ȯ'.charCodeAt()),
			new Key('ö'.charCodeAt()),
			new Key('ỏ'.charCodeAt()),
			new Key('ő'.charCodeAt()),
			new Key('ǒ'.charCodeAt()),
			new Key('ȍ'.charCodeAt()),
			new Key('ȏ'.charCodeAt()),
			new Key('ơ'.charCodeAt()),
			new Key('ǫ'.charCodeAt()),
			new Key('ọ'.charCodeAt()),
			new Key('ɵ'.charCodeAt()),
			new Key('ø'.charCodeAt()),
			new Key('ồ'.charCodeAt()),
			new Key('ố'.charCodeAt()),
			new Key('ỗ'.charCodeAt()),
			new Key('ổ'.charCodeAt()),
			new Key('ȱ'.charCodeAt()),
			new Key('ȫ'.charCodeAt()),
			new Key('ȭ'.charCodeAt()),
			new Key('ṍ'.charCodeAt()),
			new Key('ṏ'.charCodeAt()),
			new Key('ṑ'.charCodeAt()),
			new Key('ṓ'.charCodeAt()),
			new Key('ờ'.charCodeAt()),
			new Key('ớ'.charCodeAt()),
			new Key('ỡ'.charCodeAt()),
			new Key('ở'.charCodeAt()),
			new Key('ợ'.charCodeAt()),
			new Key('ǭ'.charCodeAt()),
			new Key('ộ'.charCodeAt()),
			new Key('ǿ'.charCodeAt()),
			new Key('ɔ'.charCodeAt()),
			new Key('œ'.charCodeAt())
		]
		
		/** Latin letter P variants */
		public static const P:Vector.<Key> = new <Key>[
			new Key('ṕ'.charCodeAt()),
			new Key('ṗ'.charCodeAt()),
			new Key('ƥ'.charCodeAt())
		];
		
		/** Latin letter Q variants */
		public static const Q:Vector.<Key> = new <Key>[];
		
		/** Latin letter R variants */
		public static const R:Vector.<Key> = new <Key>[
			new Key('ŕ'.charCodeAt()),
			new Key('ṙ'.charCodeAt()),
			new Key('ř'.charCodeAt()),
			new Key('ȑ'.charCodeAt()),
			new Key('ȓ'.charCodeAt()),
			new Key('ṛ'.charCodeAt()),
			new Key('ŗ'.charCodeAt()),
			new Key('ṟ'.charCodeAt()),
			new Key('ṝ'.charCodeAt())
		];
		
		/** Latin letter S variants */
		public static const S:Vector.<Key> = new <Key>[
			new Key('ś'.charCodeAt()),
			new Key('ŝ'.charCodeAt()),
			new Key('ṡ'.charCodeAt()),
			new Key('š'.charCodeAt()),
			new Key('ṣ'.charCodeAt()),
			new Key('ș'.charCodeAt()),
			new Key('ş'.charCodeAt()),
			new Key('ṥ'.charCodeAt()),
			new Key('ṧ'.charCodeAt()),
			new Key('ṩ'.charCodeAt()),
			new Key('ß'.charCodeAt()),
			new Key('ſ'.charCodeAt()),
			new Key('ẛ'.charCodeAt())
		];
		
		/** Latin letter T variants */
		public static const T:Vector.<Key> = new <Key>[
			new Key('ṫ'.charCodeAt()),
			new Key('ẗ'.charCodeAt()),
			new Key('ť'.charCodeAt()),
			new Key('ƭ'.charCodeAt()),
			new Key('ʈ'.charCodeAt()),
			new Key('ƫ'.charCodeAt()),
			new Key('ṭ'.charCodeAt()),
			new Key('ț'.charCodeAt()),
			new Key('ţ'.charCodeAt()),
			new Key('ṱ'.charCodeAt()),
			new Key('ṯ'.charCodeAt()),
			new Key('ŧ'.charCodeAt()),
			new Key('ȶ'.charCodeAt())
		];
	
		/** Latin letter U variants */
		public static const U:Vector.<Key> = new <Key>[
			new Key('ù'.charCodeAt()),
			new Key('ú'.charCodeAt()),
			new Key('û'.charCodeAt()),
			new Key('ũ'.charCodeAt()),
			new Key('ū'.charCodeAt()),
			new Key('ŭ'.charCodeAt()),
			new Key('ü'.charCodeAt()),
			new Key('ủ'.charCodeAt()),
			new Key('ů'.charCodeAt()),
			new Key('ű'.charCodeAt()),
			new Key('ǔ'.charCodeAt()),
			new Key('ȕ'.charCodeAt()),
			new Key('ȗ'.charCodeAt()),
			new Key('ư'.charCodeAt()),
			new Key('ụ'.charCodeAt()),
			new Key('ṳ'.charCodeAt()),
			new Key('ų'.charCodeAt()),
			new Key('ṷ'.charCodeAt()),
			new Key('ṵ'.charCodeAt()),
			new Key('ṹ'.charCodeAt()),
			new Key('ṻ'.charCodeAt()),
			new Key('ǖ'.charCodeAt()),
			new Key('ǜ'.charCodeAt()),
			new Key('ǘ'.charCodeAt()),
			new Key('ǖ'.charCodeAt()),
			new Key('ǚ'.charCodeAt()),
			new Key('ừ'.charCodeAt()),
			new Key('ứ'.charCodeAt()),
			new Key('ữ'.charCodeAt()),
			new Key('ử'.charCodeAt()),
			new Key('ự'.charCodeAt())
		];

		/** Latin letter V variants */
		public static const V:Vector.<Key> = new <Key>[
			new Key('ṽ'.charCodeAt()),
			new Key('ṿ'.charCodeAt())
		];

		/** Latin letter W variants */
		public static const W:Vector.<Key> = new <Key>[
			new Key('ẁ'.charCodeAt()),
			new Key('ẃ'.charCodeAt()),
			new Key('ŵ'.charCodeAt()),
			new Key('ẇ'.charCodeAt()),
			new Key('ẅ'.charCodeAt()),
			new Key('ẘ'.charCodeAt()),
			new Key('ẉ'.charCodeAt())
		];

		/** Latin letter X variants */
		public static const X:Vector.<Key> = new <Key>[
			new Key('ẋ'.charCodeAt()),
			new Key('ẍ'.charCodeAt())
		];
		
		/** Latin letter Y variants */
		public static const Y:Vector.<Key> = new <Key>[
			new Key('ỳ'.charCodeAt()),
			new Key('ý'.charCodeAt()),
			new Key('ŷ'.charCodeAt()),
			new Key('ȳ'.charCodeAt()),
			new Key('ẏ'.charCodeAt()),
			new Key('ÿ'.charCodeAt()),
			new Key('ỷ'.charCodeAt()),
			new Key('ẙ'.charCodeAt()),
			new Key('ƴ'.charCodeAt()),
			new Key('ỵ'.charCodeAt())
		];

		/** Latin letter Z variants */
		public static const Z:Vector.<Key> = new <Key>[
			new Key('ź'.charCodeAt()),
			new Key('ẑ'.charCodeAt()),
			new Key('ż'.charCodeAt()),
			new Key('ž'.charCodeAt()),
			new Key('ȥ'.charCodeAt()),
			new Key('ẓ'.charCodeAt()),
			new Key('ẕ'.charCodeAt()),
			new Key('ƶ'.charCodeAt())
		];
		
	}
	
}